@@ -2,7 +2,7 @@ package HTML::Selector::XPath;
 
 use strict;
 use 5.008_001;
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 require Exporter;
 our @EXPORT_OK = qw(selector_to_xpath);
@@ -49,7 +49,7 @@ sub convert_attribute_match {
     } elsif ($op eq '~=') { # substring attribute match
         "contains(concat(' ', \@$left, ' '), ' $right ')";
     } elsif ($op eq '*=') { # real substring attribute match
-        "contains($left, '$right')";
+        "contains(\@$left, '$right')";
     } elsif ($op eq '|=') {
         "\@$left='$right' or starts-with(\@$left, '$right-')";
     } elsif ($op eq '^=') {
@@ -175,7 +175,9 @@ sub to_xpath {
 
         # Ignore pseudoclasses/pseudoelements
         while ($rule =~ s/$reg->{pseudo}//) {
-            if ( $1 eq 'first-child') {
+            if ( my @expr = $self->parse_pseudo($1, \$rule) ) {
+                push @parts, @expr;
+            } elsif ( $1 eq 'first-child') {
                 # Translates to :nth-child(1)
                 push @parts, nth_child(1);
             } elsif ( $1 eq 'last-child') {
@@ -242,6 +244,10 @@ sub to_xpath {
     return join '', @parts;
 }
 
+sub parse_pseudo { 
+    # nop
+}    
+
 1;
 __END__
 
@@ -298,6 +304,20 @@ defaults to C</>.
 
 =back
 
+=head1 SUBCLASSING NOTES
+
+=over 4
+
+=item parse_pseudo
+
+This method is called during xpath construction when we encounter a pseudo 
+selector (something that begins with comma). It is passed the selector and 
+a reference to the string we are parsing. It should return one or more 
+xpath sub-expressions to add to the parts if the selector is handled, 
+otherwise return an empty list.
+
+=back
+
 =head1 CAVEATS
 
 =head2 CSS SELECTOR VALIDATION
